Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1960)

Unified Diff: chrome/browser/password_manager/chrome_password_manager_client.cc

Issue 839193002: Move ServiceAccessType into //components/keyed_service (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix compilation on android Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/password_manager/chrome_password_manager_client.cc
diff --git a/chrome/browser/password_manager/chrome_password_manager_client.cc b/chrome/browser/password_manager/chrome_password_manager_client.cc
index f5604c40af73aab566eaae846565872c5db21f90..a69d75cc400baba6de89d137f20963f192f4d326 100644
--- a/chrome/browser/password_manager/chrome_password_manager_client.cc
+++ b/chrome/browser/password_manager/chrome_password_manager_client.cc
@@ -266,9 +266,10 @@ password_manager::PasswordStore*
ChromePasswordManagerClient::GetPasswordStore() {
// Always use EXPLICIT_ACCESS as the password manager checks IsOffTheRecord
// itself when it shouldn't access the PasswordStore.
- // TODO(gcasto): Is is safe to change this to Profile::IMPLICIT_ACCESS?
- return PasswordStoreFactory::GetForProfile(profile_, Profile::EXPLICIT_ACCESS)
- .get();
+ // TODO(gcasto): Is is safe to change this to
+ // ServiceAccessType::IMPLICIT_ACCESS?
+ return PasswordStoreFactory::GetForProfile(
+ profile_, ServiceAccessType::EXPLICIT_ACCESS).get();
}
base::FieldTrial::Probability

Powered by Google App Engine
This is Rietveld 408576698